from pyramid.configuration import Configurator
from pyramid_jinja2 import renderer_factory
from pyramid.settings import asbool

from helloworld.models import appmaker

def app(global_config, **settings):
    """ This function returns a WSGI application.
    
    It is usually called by the PasteDeploy framework during 
    ``paster serve``.
    """
    db_string = settings.get('db_string')
    if db_string is None:
        raise ValueError("No 'db_string' value in application configuration.")
    db_echo = settings.get('db_echo', 'false')
    get_root = appmaker(db_string, asbool(db_echo))
    config = Configurator(root_factory=get_root, settings=settings)
    config.begin()
    config.add_renderer('.jinja2', renderer_factory)
    config.add_static_view('static', 'static')
    config.add_view('helloworld.views.string_hello')
    config.add_view('helloworld.views.raw_sql',
                    name='raw_sql')
    config.add_view('helloworld.views.jinja_hello',
                    name='jinja_hello',
                    renderer="hello.jinja2")
    config.add_view('helloworld.views.jinja_sql',
                    name='jinja_sql',
                    renderer="db.jinja2")
    config.end()
    return config.make_wsgi_app()
